==> haskell-half-0.3-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 half
version:              0.3
visibility:           public
id:                   half-0.3-LVtm4rOV9w2yWfbfGRDih
key:                  half-0.3-LVtm4rOV9w2yWfbfGRDih
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  8dabebd6be3eac2699a69da06b7d43d8
exposed:              True
exposed-modules:      Numeric.Half
import-dirs:          /usr/lib/ghc-8.10.2/site-local/half-0.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/half-0.3
hs-libraries:         HShalf-0.3-LVtm4rOV9w2yWfbfGRDih
depends:
    base-4.14.1.0 deepseq-1.4.4.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-half-0.3-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 half
version:              0.3
visibility:           public
id:                   half-0.3-K0lrtfuAaER2FESq3VAKcK
key:                  half-0.3-K0lrtfuAaER2FESq3VAKcK
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  93a0f0096e59f6ab1be282bef7113a3e
exposed:              True
exposed-modules:      Numeric.Half
import-dirs:          /usr/lib/ghc-8.10.2/site-local/half-0.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/half-0.3
hs-libraries:         HShalf-0.3-K0lrtfuAaER2FESq3VAKcK
depends:
    base-4.14.1.0 deepseq-1.4.4.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
